@@ -7,10 +7,12 @@
 #' @param x An object resulting from one of the `tune_*()` functions,
 #'  `fit_resamples()`, or `last_fit()`. The control specifications for these
 #'  objects should have used the option `save_pred = TRUE`.
+#' @param ... Not currently used.
 #' @param parameters A data frame with a single row that indicates what
 #' tuning parameters should be used to generate the predictions (for `tune_*()`
-#' objects only). If `NULL`, `select_best(x)` will be used.
-#' @param ... Not currently used.
+#' objects only). If `NULL`, `select_best(x)` will be used with the first
+#' metric and, if applicable, the first evaluation time point, used to
+#' create `x`.
 #' @return A data frame with one or more additional columns for model
 #' predictions.
 #'
@@ -32,22 +34,19 @@
 #' results.
 #'
 #' @export
-augment.tune_results <- function(x, parameters = NULL, ...) {
-  dots <- rlang::list2(...)
-  if (length(dots) > 0) {
-    rlang::abort(
-      paste(
-        "The only two arguments for `augment.tune_results()` are",
-        "'x' and 'parameters'. Others were passed:",
-        paste0("'", names(dots), "'", collapse = ", ")
-      )
-    )
-  }
+augment.tune_results <- function(x, ..., parameters = NULL) {
+  rlang::check_dots_empty()
 
   # check/determine best settings
   if (is.null(parameters)) {
     obj_fun <- .get_tune_metric_names(x)[1]
-    parameters <- select_best(x, metric = obj_fun)
+    obj_eval_time <- choose_eval_time(
+      x,
+      metric = obj_fun,
+      eval_time = NULL,
+      quietly = TRUE
+    )
+    parameters <- select_best(x, metric = obj_fun, eval_time = obj_eval_time)
   } else {
     if (!is.data.frame(parameters) || nrow(parameters) > 1) {
       rlang::abort("'parameters' should be a single row data frame")
@@ -62,16 +61,7 @@ augment.tune_results <- function(x, parameters = NULL, ...) {
 #' @rdname augment.tune_results
 #' @export
 augment.resample_results <- function(x, ...) {
-  dots <- rlang::list2(...)
-  if (length(dots) > 0) {
-    rlang::abort(
-      paste(
-        "The only argument for `augment.fit_resamples()` is",
-        "'x'. Others were passed:",
-        paste0("'", names(dots), "'", collapse = ", ")
-      )
-    )
-  }
+  rlang::check_dots_empty()
 
   pred <- collect_predictions(x, summarize = TRUE)
   y_nm <- .get_tune_outcome_names(x)
@@ -83,16 +73,7 @@ augment.resample_results <- function(x, ...) {
 #' @rdname augment.tune_results
 #' @export
 augment.last_fit <- function(x, ...) {
-  dots <- rlang::list2(...)
-  if (length(dots) > 0) {
-    rlang::abort(
-      paste(
-        "The only argument for `augment.last_fit()` is",
-        "'x'. Others were passed:",
-        paste0("'", names(dots), "'", collapse = ", ")
-      )
-    )
-  }
+  rlang::check_dots_empty()
 
   pred <- collect_predictions(x, summarize = TRUE)
   pred$.row <- 1:nrow(pred)
@@ -107,16 +88,23 @@ merge_pred <- function(dat, pred, y) {
   if (nrow(pred) != nrow(dat)) {
     rlang::warn(
       paste(
-        "The orginal data had", nrow(dat), "rows but there were",
+        "The original data had", nrow(dat), "rows but there were",
         nrow(pred), "hold-out predictions."
       )
     )
   }
+
+  if (!tibble::is_tibble(dat)) {
+    dat <- tibble::as_tibble(dat)
+  }
+
   dat$.row <- 1:nrow(dat)
   dat <- dplyr::left_join(dat, pred, by = ".row")
   dat$.row <- NULL
   if (all(pred_cols == ".pred")) {
     dat$.resid <- dat[[y]] - dat$.pred
   }
+  dat <- dplyr::relocate(dat, dplyr::starts_with("."))
+
   dat
 }
