@@ -7,6 +7,9 @@ pred_type <- function(x) {
     cls == "class_metric" ~ "class",
     cls == "prob_metric" ~ "prob",
     cls == "numeric_metric" ~ "numeric",
+    cls == "dynamic_survival_metric" ~ "survival",
+    cls == "integrated_survival_metric" ~ "survival",
+    cls == "static_survival_metric" ~ "time",
     TRUE ~ "unknown"
   )
   res
@@ -57,6 +60,14 @@ metrics_info <- function(x) {
 #' @export
 .estimate_metrics <- function(dat, metric, param_names, outcome_name, event_level,
                               metrics_info = metrics_info(metrics)) {
+  # The call stack is:
+  #
+  # tune_grid_loop_iter()
+  #   append_metrics(). <many times>
+  #    .estimate_metrics()
+
+  # predictions made in predict_model()
+
   if (inherits(dat, "try-error")) {
     return(NULL)
   }
@@ -81,6 +92,8 @@ metrics_info <- function(x) {
     estimate_reg(dat, metric, param_names, outcome_name, case_weights)
   } else if (all(types == "class" | types == "prob")) {
     estimate_class_prob(dat, metric, param_names, outcome_name, case_weights, types, event_level)
+  } else if (all(types == "time" | types == "survival")) {
+    estimate_surv(dat, metric, param_names, outcome_name, case_weights, types)
   } else {
     rlang::abort("Metric type not yet supported by tune.")
   }
@@ -129,3 +142,79 @@ estimate_class_prob <- function(dat, metric, param_names, outcome_name,
       event_level = event_level
     )
 }
+
+# ------------------------------------------------------------------------------
+
+estimate_surv <- function(dat, metric, param_names, outcome_name, case_weights, types) {
+  #  potentially need to work around submodel parameters since those are within .pred
+  dat <- unnest_parameters(dat, param_names)
+  dat %>%
+    dplyr::group_by(!!!rlang::syms(param_names)) %>%
+    metric(
+      truth = !!rlang::sym(outcome_name),
+      estimate = !!maybe_estimate(metric),
+      case_weights = !!case_weights,
+      !!maybe_surv_prob(metric)
+    )
+}
+
+unnest_parameters <- function(x, params = NULL) {
+   if (is.null(params)) {
+    return(x)
+   }
+   
+  # When multi_predict() is used, .pred will have the tuning parameter values.
+  # Other (non-submodel) parameters will be outside of 'x'.
+  # If this happens, pull the submodel parameters out of .pred and put them at
+  # the out level ('x') with the rest (if any)
+  
+  outer_nms <- names(x)
+  has_pred <- any(outer_nms == ".pred")
+   if (!has_pred) {
+    return(x)
+  }
+  
+  inner_nms <- names(x$.pred[[1]])
+  has_inner_params <- any(params %in% inner_nms)
+  if (!has_inner_params) {
+    return(x)
+  }
+
+  x <- x %>% parsnip::add_rowindex()
+
+  others <- x %>% dplyr::select(-.pred)
+  rm_cols <- c(".pred_censored", ".weight_time")
+  nest_cols <- c(".eval_time", ".pred_survival", ".weight_censored")
+  x <-
+    x %>%
+    dplyr::select(.pred, .row) %>%
+    tidyr::unnest(cols = c(.pred)) %>%
+    dplyr::select(-dplyr::any_of(rm_cols)) %>%
+    tidyr::nest(.pred = c(all_of(nest_cols)), .by = c(.row, dplyr::all_of(params))) %>%
+    dplyr::full_join(others, by = ".row") %>%
+    dplyr::select(-.row)
+  x
+}
+
+maybe_estimate <- function(x) {
+  info <- tibble::as_tibble(x)
+  if (any(info$class == "static_survival_metric")) {
+    res <- rlang::sym(".pred_time")
+  } else {
+    res <- NULL
+  }
+  res
+}
+
+maybe_surv_prob <- function(x) {
+  info <- tibble::as_tibble(x)
+  # dyn_inputs defined in checks.R
+  if (any(info$class %in% dyn_inputs)) {
+    res <- rlang::sym(".pred")
+  } else {
+    res <- NULL
+  }
+  res
+}
+
+
