@@ -8,17 +8,19 @@
 #' @return An invisible NULL.
 #' @keywords internal
 #' @export
-load_pkgs <- function(x, infra = TRUE, ...) {
+load_pkgs <- function(x, ..., infra = TRUE) {
   UseMethod("load_pkgs")
 }
 
 #' @export
 load_pkgs.character <- function(x, ...) {
+  rlang::check_dots_empty()
   withr::with_preserve_seed(.load_namespace(x))
 }
 
 #' @export
-load_pkgs.model_spec <- function(x, infra = TRUE, ...) {
+load_pkgs.model_spec <- function(x, ..., infra = TRUE) {
+  rlang::check_dots_empty()
   pkgs <- required_pkgs(x)
   if (infra) {
     pkgs <- c(infra_pkgs, pkgs)
@@ -27,7 +29,8 @@ load_pkgs.model_spec <- function(x, infra = TRUE, ...) {
 }
 
 #' @export
-load_pkgs.workflow <- function(x, infra = TRUE, ...) {
+load_pkgs.workflow <- function(x, ..., infra = TRUE) {
+  rlang::check_dots_empty()
   load_pkgs.model_spec(extract_spec_parsnip(x), infra = infra)
 }
 
