@@ -53,7 +53,10 @@ test_that("tune recipe only", {
   expect_equal(res_est$n, rep(10, iterT * 2))
   expect_false(identical(num_comp, expr(tune())))
   expect_true(res_workflow$trained)
+  expect_null(.get_tune_eval_times(res))
+  expect_null(.get_tune_eval_time_target(res))
 
+  set.seed(1)
   expect_error(
     suppressMessages(
       tune_bayes(
@@ -70,6 +73,7 @@ test_that("tune recipe only", {
 
 
   # test verbose options
+  set.seed(1)
   expect_snapshot(
     tune_bayes(
       wflow,
@@ -81,6 +85,7 @@ test_that("tune recipe only", {
     )
   )
 
+  set.seed(1)
   expect_snapshot(
     tune_bayes(
       wflow,
@@ -92,6 +97,7 @@ test_that("tune recipe only", {
     )
   )
 
+  set.seed(1)
   expect_snapshot(
     tune_bayes(
       wflow,
@@ -102,8 +108,6 @@ test_that("tune recipe only", {
       control = control_bayes(verbose_iter = TRUE, verbose = TRUE)
     )
   )
-
-
 })
 
 # ------------------------------------------------------------------------------
@@ -534,3 +538,54 @@ test_that("missing performance values", {
       )
   })
 })
+
+# ------------------------------------------------------------------------------
+test_that("tune_bayes() output for `iter` edge cases (#721)", {
+  # for `iter = 0`, ought to match `tune_grid()`
+  boots <- rsample::bootstraps(mtcars)
+  wf <-
+    workflows::workflow(
+      mpg ~ .,
+      parsnip::nearest_neighbor("regression", "kknn", neighbors = tune())
+    )
+
+  ctrl_bayes <- control_bayes(seed = 1)
+
+  set.seed(1)
+  res_bayes <- tune_bayes(wf, boots, iter = 0, initial = 10,
+                          control = ctrl_bayes)
+
+  set.seed(1)
+  res_grid <- tune_grid(wf, boots)
+
+  expect_equal(
+    collect_metrics(res_bayes) %>% dplyr::select(-.iter),
+    collect_metrics(res_grid)
+  )
+
+  # for `iter < 0`, ought to error
+  expect_snapshot(
+    error = TRUE,
+    tune_bayes(wf, boots, iter = -1)
+  )
+
+  expect_snapshot(
+    error = TRUE,
+    tune_bayes(wf, boots, iter = c(-1, 0, 1))
+  )
+
+  expect_snapshot(
+    error = TRUE,
+    tune_bayes(wf, boots, iter = c(0, 1, 2))
+  )
+
+  expect_snapshot(
+    error = TRUE,
+    tune_bayes(wf, boots, iter = NA)
+  )
+
+  expect_snapshot(
+    error = TRUE,
+    tune_bayes(wf, boots, iter = NULL)
+  )
+})
