@@ -47,7 +47,7 @@ svm_tune_class$.predictions <-
   )
 attr(svm_tune_class, "metrics") <- yardstick::metric_set(yardstick::kap)
 
-svm_grd <- show_best(svm_tune, "roc_auc") %>% dplyr::select(`cost value`)
+svm_grd <- show_best(svm_tune, metric = "roc_auc") %>% dplyr::select(`cost value`)
 
 # ------------------------------------------------------------------------------
 
@@ -57,6 +57,13 @@ test_that("`collect_predictions()` errors informatively if there is no `.predict
   })
 })
 
+test_that("`collect_predictions()` errors informatively applied to unsupported class", {
+  expect_snapshot(
+    error = TRUE,
+    collect_predictions(lm(mpg ~ disp, mtcars))
+  )
+})
+
 # ------------------------------------------------------------------------------
 
 test_that("`collect_predictions()`, un-averaged", {
@@ -114,8 +121,8 @@ test_that("classification class predictions, averaged", {
   expect_false(dplyr::is_grouped_df(res))
   expect_named(
     collect_predictions(svm_tune, summarize = TRUE),
-    c(".row", "cost value", "Class", ".config", ".iter", ".pred_Class1",
-      ".pred_Class2", ".pred_class")
+    c(".pred_class", ".pred_Class1", ".pred_Class2", ".row", "cost value",
+      "Class", ".config", ".iter")
   )
 
   # pull out an example to test
@@ -197,6 +204,13 @@ test_that("collecting notes - last_fit", {
   expect_equal(names(nts), c("location", "type", "note"))
 })
 
+test_that("`collect_notes()` errors informatively applied to unsupported class", {
+  expect_snapshot(
+    error = TRUE,
+    collect_notes(lm(mpg ~ disp, mtcars))
+  )
+})
+
 test_that("collecting extracted objects - fit_resamples", {
   # skip pre-R-4.0.0 so that snaps aren't affected by stringsAsFactors change
   skip_if(R.Version()$major < "4")
@@ -218,5 +232,120 @@ test_that("collecting extracted objects - fit_resamples", {
   expect_snapshot(collect_extracts(res_fit))
   expect_snapshot(collect_extracts(res_nothing), error = TRUE)
   expect_snapshot(collect_extracts(res_error))
-  expect_snapshot(collect_extracts("boop"), error = TRUE)
 })
+
+test_that("`collect_extracts()` errors informatively applied to unsupported class", {
+  expect_snapshot(
+    error = TRUE,
+    collect_extracts(lm(mpg ~ disp, mtcars))
+  )
+})
+
+test_that("`collect_metrics()` errors informatively applied to unsupported class", {
+  expect_snapshot(
+    error = TRUE,
+    collect_metrics(lm(mpg ~ disp, mtcars))
+  )
+})
+
+test_that("`collect_metrics(type)` errors informatively with bad input", {
+  skip_on_cran()
+
+  expect_snapshot(
+    error = TRUE,
+    collect_metrics(ames_grid_search, type = "boop")
+  )
+
+  expect_snapshot(
+    error = TRUE,
+    collect_metrics(ames_grid_search, type = NULL)
+  )
+})
+
+test_that("`pivot_metrics()`, grid search, typical metrics, summarized", {
+  expect_equal(
+    pivot_metrics(ames_grid_search, collect_metrics(ames_grid_search)) %>%
+      dplyr::slice(),
+    tibble::tibble(
+      K = integer(0),
+      weight_func = character(0),
+      dist_power = numeric(0),
+      lon = integer(0),
+      lat = integer(0),
+      .config = character(0),
+      rmse = numeric(0),
+      rsq = numeric(0)
+    )
+  )
+})
+
+test_that("`pivot_metrics()`, grid search, typical metrics, unsummarized", {
+  expect_equal(
+    pivot_metrics(
+      ames_grid_search,
+      collect_metrics(ames_grid_search, summarize = FALSE)
+    ) %>%
+      dplyr::slice(),
+    tibble::tibble(
+      K = integer(0),
+      weight_func = character(0),
+      dist_power = numeric(0),
+      lon = integer(0),
+      lat = integer(0),
+      .config = character(0),
+      id = character(0),
+      rmse = numeric(0),
+      rsq = numeric(0)
+    )
+  )
+})
+
+test_that("`pivot_metrics()`, iterative search, typical metrics, summarized", {
+  expect_equal(
+    pivot_metrics(ames_iter_search, collect_metrics(ames_iter_search)) %>%
+      dplyr::slice(),
+    tibble::tibble(
+      K = integer(0),
+      weight_func = character(0),
+      dist_power = numeric(0),
+      lon = integer(0),
+      lat = integer(0),
+      .config = character(0),
+      .iter = integer(0),
+      rmse = numeric(0),
+      rsq = numeric(0)
+    )
+  )
+})
+
+test_that("`pivot_metrics()`, resampled fits, fairness metrics, summarized", {
+  mtcars_fair <- mtcars
+  mtcars_fair$vs <- as.factor(mtcars_fair$vs)
+  mtcars_fair$cyl <- as.factor(mtcars_fair$cyl)
+  mtcars_fair$am <- as.factor(mtcars_fair$am)
+  set.seed(4400)
+
+  ms <-
+    yardstick::metric_set(
+      yardstick::demographic_parity(cyl),
+      yardstick::demographic_parity(am)
+    )
+
+  res <-
+    fit_resamples(
+      nearest_neighbor("classification"),
+      vs ~ mpg + hp + cyl,
+      rsample::bootstraps(mtcars_fair, 3),
+      metrics = ms
+    )
+
+  expect_equal(
+    pivot_metrics(res, collect_metrics(res)) %>% slice(),
+    tibble::tibble(
+      .config = character(0),
+      `demographic_parity(am)` = integer(0),
+      `demographic_parity(cyl)` = numeric(0),
+    )
+  )
+})
+
