@@ -291,7 +291,9 @@ test_that("left_join() can keep tune_results class if tune_results structure is
 test_that("left_join() can lose tune_results class if rows are added", {
   for (x in helper_tune_results) {
     y <- tibble(id = x$id[[1]], x = 1:2)
-    expect_s3_class_bare_tibble(left_join(x, y, by = "id", multiple = "all"))
+    expect_s3_class_bare_tibble(
+      left_join(x, y, by = "id", relationship = "many-to-many")
+    )
   }
 })
 
@@ -318,7 +320,9 @@ test_that("right_join() can keep tune_results class if tune_results structure is
 test_that("right_join() can lose tune_results class if rows are added", {
   for (x in helper_tune_results) {
     y <- tibble(id = x$id[[1]], x = 1:2)
-    expect_s3_class_bare_tibble(right_join(x, y, by = "id", multiple = "all"))
+    expect_s3_class_bare_tibble(
+      right_join(x, y, by = "id", relationship = "many-to-many")
+    )
   }
 })
 
